package com.ynet.life.sujrb.file.download;

import com.ynet.gene.core.Context;
import com.ynet.gene.data.InvalidArgumentException;
import com.ynet.gene.data.ObjectNotFoundException;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.FileAccessDeniedException;
import com.ynet.life.file.download.FileAccessValidator;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;

/* loaded from: com_ynet_life_sujrb_file_download.jar:com/ynet/life/sujrb/file/download/PBFileAccessValidator.class */
public class PBFileAccessValidator implements FileAccessValidator {
    public void validate(String filePath, Context sessionContext) throws FileAccessDeniedException {
        String downloadRootDir = LifeStandard.getSelfDefineSettingsValue("fileDownloadPath");
        try {
            downloadRootDir = new File(downloadRootDir).getCanonicalPath();
            try {
                filePath = new File(filePath).getCanonicalPath();
                if (filePath.indexOf(downloadRootDir) != 0) {
                    throw new FileAccessDeniedException();
                }
                if (sessionContext != null) {
                    try {
                        sessionContext.getDataValue("session_customerId");
                        new File(filePath).getParentFile().getName();
                    } catch (InvalidArgumentException e) {
                        Trace.logError("LifeAction", "sessionID无效", e);
                        throw new FileAccessDeniedException(e);
                    } catch (ObjectNotFoundException e2) {
                        Trace.logError("LifeAction", "session_customerId is not defined in sessionContext", e2);
                        throw new FileAccessDeniedException("session_customerId is not defined in sessionContext", e2);
                    }
                }
            } catch (FileNotFoundException e3) {
                Trace.logError("LifeAction", "download file \"" + filePath + "\" is not exist", e3);
                throw new FileAccessDeniedException("download file \"" + filePath + "\" is not exist", e3);
            } catch (IOException e4) {
                Trace.logError("LifeAction", "i/o error occurs when reading download file \"" + filePath + "\"", e4);
                throw new FileAccessDeniedException("i/o error occurs when reading download file \"" + filePath + "\"", e4);
            }
        } catch (FileNotFoundException e5) {
            Trace.logError("LifeAction", "fileDownloadPath \"" + downloadRootDir + "\" is not exist", e5);
            throw new FileAccessDeniedException("fileDownloadPath \"" + downloadRootDir + "\" is not exist", e5);
        } catch (IOException e6) {
            Trace.logError("LifeAction", "i/o error occurs when reading tempDownloadDir \"" + downloadRootDir + "\"", e6);
            throw new FileAccessDeniedException("i/o error occurs when reading tempDownloadDir \"" + downloadRootDir + "\"", e6);
        }
    }
}
